Release 0.1.2
=============

* Added: fab command ``wsgi_restart`` to gently restart mod_wsgi by touching its config file
* Fixed #1: ``fab vagrant migrate`` now processes first migration too


Release 0.1.1
=============

* Usage documentation added
* vagrant_project: removed branch manipulation commands


Release 0.1
===========

* First public release. Includes vagrant_project template.
